package com.ruoyi.project.business.service;

import java.util.List;

import com.ruoyi.project.business.domain.TpParabar;
import com.ruoyi.project.business.domain.vo.parabar.*;

/**
 * 参数包Service接口
 * 
 * @author ruoyi
 * @date 2024-04-28
 */
public interface ITpParabarService 
{
    /**
     * 查询参数包
     * 
     * @param id 参数包主键
     * @return 参数包
     */
    public TpParabar selectTpParabarById(Long id);

    /**
     * 查询参数包列表
     * 
     * @param tpParabar 参数包
     * @return 参数包集合
     */
    public List<TpParabar> selectTpParabarList(TpParabar tpParabar);

    /**
     * 查询参数配置详情
     *
     * @param parabarVO 参数包
     * @return 参数包集合
     */
    public List<ParabarDetailVO> selectParabarDetail(ParabarVO parabarVO);

    /**
     * 获取关联梯型
     *
     * @return 区域梯型集合
     */
    public List<RelatedModelVO> getRelatedModelList(TpParabar tpParabar);

    /**
     *  获取关联梯形的共同参数
     */
    public List<CommonPara> getCommonParaList(ParaForGetCommonPara para);


    /**
     *  获取关联梯形的共同参数以及共同选项
     */
    public List<CommonPara> getCommonParaAndItemList(ParaForGetCommonPara para);

    /**
     * 新增参数包
     * 
     * @param parabarVO 参数包
     * @return 结果
     */
    public int insertTpParabar(ParabarVO parabarVO);

    /**
     * 修改参数包
     * 
     * @param tpParabar 参数包
     * @return 结果
     */
    public int updateTpParabar(ParabarVO parabarVO);

    /**
     * 批量删除参数包
     * 
     * @param ids 需要删除的参数包主键集合
     * @return 结果
     */
    public int deleteTpParabarByIds(Long[] ids);

    /**
     * 删除参数包信息
     * 
     * @param id 参数包主键
     * @return 结果
     */
    public int deleteTpParabarById(Long id);

    /**
     * 修改参数状态
     *
     * @param tpParabar 参数库
     * @return 结果
     */
    public int updateParaStatus(TpParabar tpParabar);

    List<ElParabarVO> getParabarConfigByElevatorModelId(Long id);
}
